import mpi.MPI;

public class MPJPartitionSolver {

	//------------------------------------------------------------------------
	// Parametre problemu a jeho rozdelenia
	//------------------------------------------------------------------------	

	/**
	 * Maximalna velkost problemu (pocet vah)
	 */
	public static final int MAX_INPUT_SIZE = 50;

	/**
	 * Velkost problemu, ktora sa dava v ramci jednej davky prace pre worker-a.
	 */
	public static final int WORK_LOAD_SIZE = 10;

	//------------------------------------------------------------------------
	// Tagy sprav
	//------------------------------------------------------------------------
	
	/**
	 * Tag spravy, ktorou Master posiela vstup.
	 */
	public static final int INPUT_DATA_TAG = 0;

	/**
	 * Tag spravy, ktorou Worker ziada o novu pracu
	 */
	public static final int ASK_WORK_TAG = 1;

	/**
	 * Tag spravy, ktorou Master posiela Worker procesu prefix rozdeleni.
	 */
	public static final int WORK_TAG = 2;

	/**
	 * Tag spravy, ktorou Master ziada Worker-a o finalny vysledok a zaroven mu
	 * oznamuje, ze ma skoncit.
	 */
	public static final int GET_RESULT_AND_FINISH_TAG = 3;

	//------------------------------------------------------------------------
	//------------------------------------------------------------------------
	
	/**
	 * Hlavny kod procesu.
	 * 
	 * @param args
	 *            obsahuje parametre, s ktorymi MPJ nastartoval proces a zaroven
	 *            su potrebene na spravne nastavenie MPI.
	 */
	public static void main(String[] args) {
		// Inicializujeme MPI
		MPI.Init(args);

		// Zistime rank procesu v ramci komunikatora zahrnujuceho vsetky procesy
		int rank = MPI.COMM_WORLD.Rank();

		// Na zaklade ranku sa rozhodneme, ci spustime kod mastra alebo workera
		Runnable processRole = (rank == 0) ? new Master() : new Worker();
		processRole.run();

		// Ukoncime MPI
		MPI.Finalize();
	}
}
